@@ -32,12 +32,14 @@
 	.Rdcite.env$cited <- character()
 
 	ret <- tools::toRd(db[cited])
-	# work around an Rd2HTML bug (PR18470) where newline-separated
-	# paragraphs originating from a \Sexpr aren't recognised -- except
-	# there's already a <p> on the first line
+	# Prior to R-4.6.0 (PR18470), newline-separated paragraphs
+	# originating from a \Sexpr weren't recognised by Rd2HTML. So rely
+	# on manually-produced paragraphs in HTML output, normal paragraphs
+	# elsewhere.
+	# TODO(R>=4.6.0): replace with paste(ret, collapse='\n\n')
 	paste(
-		c('', rep('\\if{html}{\\out{<p>}}', length(ret)-1)), ret,
-		collapse = '\n\n'
+		c('', rep('\\ifelse{html}{\\out{<p>}}{\n\n}', length(ret)-1)), ret,
+		collapse = '\n'
 	)
 }
 .Rdreference <- function(key) {
