@@ -17,60 +17,61 @@ cubeapply.feemcube <- function(x, fun, ...) feemcube(fun(as.list(x), ...), TRUE)
 	stop(ee)
 }
 # wrap user-provided function to unwrap the feem and call handler on error
-.wrapfun <- function(fun)
+.wrapfun <- function(fun) {
+	force(fun)
+	# NOTE: without the force(), the resulting object could serialize to 700
+	# megabytes due to `fun` seemingly being a promise. Once the promise
+	# resolves, suddenly `fun` is much more compact.
 	function(l, ...) withCallingHandlers(fun(l$x, ...), error = .wraperr(l$name))
+}
 # wrap user-provided list with names for .wrapfun to unwrap it
 .wraplist <- function(x, nm = x)
 	Map(function(x, n) list(x = x, name = n), x, nm)
 
-cubeapply.list <- function(x, fun, ..., cl, progress = TRUE, .recycle = FALSE) {
+cubeapply.list <- function(
+	x, fun, ..., cl, progress = TRUE, .recycle = FALSE,
+	chunk.size = NULL, .scheduling = c('static', 'dynamic')
+) {
 	# prepare to handle errors inside the loop
 	nm <- .cubenames(x)
 	x <- .wraplist(x, nm)
 	wfun <- .wrapfun(fun)
 	# run the loop
 	if (progress) {
-		pb <- txtProgressBar(
-			max = length(x), style = if (interactive()) 3 else 1
-		)
+		pb <- makepb(length(x))
 		on.exit(close(pb))
 	}
 	if (missing(cl)) { # sequential processing: use library functions
-		pfun <- if (progress) function(...) {
-			# increment the progress bar every time the function returns
-			on.exit(setTxtProgressBar(pb, getTxtProgressBar(pb) + 1))
-			wfun(...)
-		} else wfun
+		pfun <- if (progress) wrap_pb_callback(wfun, pb) else wfun
 		if (.recycle) mapply(
 			pfun, x, ..., SIMPLIFY = FALSE
 		) else lapply(x, pfun, ...)
 	} else {
+		# can't get default cluster on R < 3.5.0, but need length(cl)
+		cl <- maybe_default_cluster(cl)
+		if (is.null(cl)) progress <- FALSE
+		.scheduling <- match.arg(.scheduling)
 		if (progress) {
-			# how much is already done
-			i <- 0
-			# in chunks of length n
-			n <- length(clusterEvalQ(cl, 1))
-			# store returned values here
-			ret <- list()
-			while (i < length(x)) {
-				# chunk must not exceed total work size
-				todo <- (i+1):min(length(x), i + n)
-				ret[todo] <- if (.recycle) do.call(clusterMap, c(
-					# .recycle = TRUE is like Map(): need to subset all
-					# arguments, not only x
-					list(cl, wfun, x[todo]), lapply(list(...), `[`, todo)
-				)) else parLapply(cl, x[todo], wfun, ...)
-				i <- max(todo)
-				if (progress) setTxtProgressBar(pb, i)
+			nchunks <- if (.recycle) length(x) else {
+				# logic taken from parallel:::staticNChunks, dynamicNChunks
+				if (is.null(chunk.size))
+					length(cl) * (1 + (.scheduling == 'dynamic'))
+				else if (chunk.size <= 0)
+					c(length(cl), length(x))[1 + (.scheduling == 'dynamic')]
+				else
+					max(1, ceiling(length(x) / chunk.size))
 			}
-			setNames(ret, names(x))
-		} else {
-			if (.recycle) clusterMap(
-				cl, wfun, x, ...
-			) else parLapply(
-				cl, x, wfun, ...
-			)
+			pb <- makepb(nchunks)
+			on.exit(close(pb), add = TRUE)
+			cl <- wrap_cluster(cl, make_pb_callback(pb))
+			on.exit(unwrap_cluster(cl), add = TRUE)
 		}
+		if (.recycle) clusterMap(
+			cl, wfun, x, ..., .scheduling = .scheduling
+		) else switch(.scheduling,
+			static = parLapply,
+			dynamic = parLapplyLB
+		)(cl, x, wfun, ..., chunk.size = chunk.size)
 	}
 }
 
