@@ -20,26 +20,26 @@ arrange <- function(x, n, m, kind) if (
 	x
 } else stop(
 	'Failed to look up ', kind, ' corresponding to the ',
-	'fluorescence spectra:\n',
+	'spectra:\n',
 	if (is.null(names(x)) || is.null(n)) c(
 		if (is.null(names(x))) ' * No names for ', kind, '\n',
-		if (is.null(n)) ' * No names for fluorescence spectra\n',
+		if (is.null(n)) ' * No names for the spectra\n',
 		if (length(x) != m) paste(
-			' * Have', m, 'fluorescence spectra but', length(x),
+			' * Have', m, ' spectra but', length(x),
 			kind, '\n'
 		)
 	) else c(
 		if (anyDuplicated(n)) paste(
-			' * The following fluorescence spectra have duplicated names:',
+			' * The following spectra have duplicated names:',
 			paste(dQuote(unique(n[duplicated(n)])), collapse = ', '), '\n'
 		),
 		if (any(!n %in% names(x))) paste0(
-			' * The following fluorescence spectra don\'t have ',
+			' * The following spectra don\'t have ',
 			'corresponding ', kind, ': ',
 			paste(dQuote(setdiff(n, names(x))), collapse = ', '), '\n'
 		),
 		if (length(x) == m) paste(
-			' * Since both fluorescence spectra and', kind,
+			' * Since both spectra and', kind,
 			'are named, refusing to match them despite having', m,
 			'spectra in both datasets\n'
 		)
@@ -54,7 +54,7 @@ feemife.list <- function(x, absorbance, abs.path, ..., progress = FALSE) {
 	stopifnot(length(list(...)) == 0)
 	cubeapply(
 		x, feemife,
-		arrange(abs2list(absorbance), names(x), length(x), 'absorbance spectra'),
+		arrange(abs2list(absorbance), names(x), length(x), 'absorbance data'),
 		arrange(abs.path, names(x), length(x), 'cell lengths'),
 		progress = progress, .recycle = TRUE
 	)
