@@ -16,7 +16,7 @@ feemparafac <- function(
 	time <- system.time(
 		for (i in seq_len(retries)) {
 			ret <- parafac(
-				cube[,,subset], output = 'best', ...,
+				cube[,, subset, drop = FALSE], output = 'best', ...,
 				const = const, ctol = ctol
 			)
 			if (ret$cflag != 2) break
@@ -92,7 +92,8 @@ residuals.feemparafac <- function(object, ...) {
 
 coef.feemparafac <- function(
 	object, type = c(
-		'all', 'scores', 'loadings', 'surfaces', 'emission', 'excitation', 'samples'
+		'all', 'scores', 'loadings', 'surfaces', 'emission', 'excitation',
+		'samples', 'scores.sum', 'scores.peak', 'scores.int'
 	), ...
 ) {
 	stopifnot(length(list(...)) == 0)
@@ -116,6 +117,47 @@ coef.feemparafac <- function(
 			)
 		},
 		scores = coef(object, 'samples'),
+		scores.sum = within(
+			merge(
+				coef(object, 'samples'),
+				data.frame(
+					factor = seq_len(ncol(object$A)),
+					mul = colSums(krprod(object$A, object$B))
+				)
+			),
+			{ value <- value * mul; rm(mul) }
+		),
+		scores.peak = within(
+			merge(
+				coef(object, 'samples'),
+				data.frame(
+					factor = seq_len(ncol(object$A)),
+					mul = apply(object$A, 2, max) * apply(object$B, 2, max)
+				)
+			),
+			{ value <- value * mul; rm(mul) }
+		),
+		scores.int = {
+			# using the 2-D equivalent of the trapezoidal rule
+			info <- .metadata.feemparafac(object)
+			mul <- diff(info$emission) %o% diff(info$excitation) / 4
+			within(
+				merge(
+					coef(object, 'samples'),
+					data.frame(
+						factor = seq_len(ncol(object$C)),
+						mul = vapply(seq_len(ncol(object$C)), function(r) {
+							AB <- object$A[,r] %o% object$B[,r]
+							sum(mul * (
+								AB[-nrow(AB),-ncol(AB)] + AB[-1,-ncol(AB)] +
+								AB[-nrow(AB),-1] + AB[-1,-1]
+							))
+						}, 0)
+					)
+				),
+				{ value <- value * mul; rm(mul) }
+			)
+		},
 		all = lapply(
 			setNames(nm = c('emission', 'excitation', 'samples')),
 			function(n) coef(object, n)
