@@ -291,7 +291,7 @@ coefshtcc <- function(object)
 			tcc = as.vector(tcc),
 			test = as.factor(col(tcc)),
 			subset = I(subsets[col(tcc)]),
-			nfac = as.factor(object$nfac[i])
+			nfac = as.factor(object$nfac[[i]])
 		)
 	}))
 
